@@ -1,14 +1,13 @@
 import logging
 from types import TracebackType
-from typing import Generator, Optional, Type, TypeVar, Iterable
+from typing import Optional, Type, Any
 
 import httpx
 import pydantic
 
 from .absent import ABSENT
 from .params import ParamPlacement
-
-T = TypeVar('T')
+from .response import _handle_response, T
 
 logger = logging.getLogger(__name__)
 
@@ -40,7 +39,7 @@ class ApiBase:
             method: str,
             url: str,
             param_model: Optional[pydantic.BaseModel] = None,
-            request_body: Optional[pydantic.BaseModel] = None,
+            request_body: Any = None,
             response_map: Optional[dict[str, dict[str, Type]]] = None,
             auth: Optional[httpx.Auth] = None,
     ) -> T:
@@ -71,21 +70,19 @@ class ApiBase:
         else:
             params = headers = cookies = None
 
-        data = request_body.dict(by_alias=True, exclude_unset=True, exclude_defaults=True) if request_body is not None else None
+        if not isinstance(request_body, pydantic.BaseModel):
+            from pydantic.tools import _get_parsing_type
+            model_type = _get_parsing_type(type(request_body))
+            request_body = model_type(__root__=request_body)
 
-        return self._client.build_request(method, url, data=data, params=params, headers=headers, cookies=cookies)
+        content = (
+            request_body.json(by_alias=True, exclude_unset=True, exclude_defaults=True)
+            if request_body is not None
+            else None)
 
-
-def _handle_response(response: httpx.Response, response_mapping: Optional[dict[str, dict[str, Type[T]]]] = None) -> T:
-    if response_mapping:
-        response_obj = resolve_response(response, response_mapping)
-        if isinstance(response_obj, Exception):
-            raise response_obj
-        else:
-            return response_obj
-    else:
-        response.raise_for_status()
-        return response.json()
+        return self._client.build_request(
+            method, url, content=content, params=params, headers=headers, cookies=cookies,
+        )
 
 
 def process_params(model: pydantic.BaseModel) -> (httpx.QueryParams, httpx.Headers, httpx.Cookies):
@@ -113,55 +110,3 @@ def process_params(model: pydantic.BaseModel) -> (httpx.QueryParams, httpx.Heade
             raise ValueError(placement)
 
     return httpx.QueryParams(query), headers, cookies
-
-
-def resolve_response(response: httpx.Response, mapping: dict[str, dict[str, Type[T]]]) -> T:
-    code_match = find_code_mapping(str(response.status_code), mapping)
-    data = response.json()
-
-    if code_match is None:
-        response.raise_for_status()
-        return data
-
-    mime_mapping = mapping[code_match]
-    mime_match = find_mime(mime_mapping.keys(), response.headers['content-type'])
-
-    if mime_match is not None:
-        typ = mime_mapping[mime_match]
-
-        if Exception in typ.mro():
-            return typ(data)
-
-        try:
-            return pydantic.parse_obj_as(typ, data)
-        except pydantic.ValidationError:
-            raise ValueError('Error parsing response as type', typ)
-
-    else:
-        response.raise_for_status()
-        return data
-
-
-def find_code_mapping(code: str, mapping: dict[str, dict[str, Type]]) -> Optional[str]:
-    for code_match in _status_code_matches(code):
-        if code_match in mapping:
-            return code_match
-    else:
-        return None
-
-
-def find_mime(supported_mimes: Iterable[str], response_mime: str) -> str:
-    from mimeparse import best_match
-    match = best_match(supported_mimes, response_mime)
-    return match if match != '' else None
-
-
-def _status_code_matches(code: str) -> Generator[str, None, None]:
-    yield code
-
-    code_as_list = list(code)
-    for pos in [-1, -2]:
-        code_as_list[pos] = 'X'
-        yield ''.join(code_as_list)
-
-    yield 'default'
